#
# spec file for package emacs-vm
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           emacs-vm
Version:        8.2.0b.1538
Release:        bp160.1.12
Summary:        VM - a mail reader for GNU Emacs
License:        GPL-2.0+
Group:          Productivity/Text/Editors
Url:            http://www.nongnu.org/viewmail/
# This is Launchpad trunk https://launchpad.net/vm/trunk - thus no URI, sorry.
Source:         vm-%{version}.tgz
Source2:        emacs-vm-autoload.el
# PATCH-FIX-UPSTREAM U_rev-1313.patch bsc#939497 eich@suse.com -- Fix Launchpad lp#793541 and lp#907286
Patch0:         vcard-Make-vcard-parser-more-robust-to-invalid-vcards.patch
# For 'trunk':
BuildRequires:  autoconf
BuildRequires:  emacs-nox
BuildRequires:  makeinfo
Requires:       ed
Requires:       emacs
%if 0%{?suse_version} <= 1500
Requires(post): %{install_info_prereq}
Requires(pre):  %{install_info_prereq}
%endif

%description
VM (View Mail) is an Emacs subsystem that allows UNIX mail to be read
and disposed of within Emacs.  Commands exist to do the normal things
expected of a mail user agent, such as generating replies, saving
messages to folders, deleting messages and so on.  There are other more
advanced commands that do tasks like bursting and creating digests,
message forwarding, and organizing message presentation according to
various criteria.

%define _sitedir %{_prefix}/share/emacs/site-lisp
%define _vmdir  %{_sitedir}/vm
%define _infodir %{_prefix}/share/info
%define _vmetcdir %{_prefix}/share/emacs/${emacs_ver}/etc/vm
%define _vmdocdir %{_prefix}/share/doc/packages/%{name}

%prep
%setup -q -n ~vm/vm/trunk
# For trunk
%autopatch -p3

%build
export LC_CTYPE=ISO-8859-1
export EMACS_UNIBYTE=1
EMACS="emacs --no-site"
emacs_ver=$(rpm -q --qf '%%{VERSION}' emacs)
rm -rf lisp/*.elc
# For trunk
autoconf
%configure FLAGS="-batch -q -no-site-file -no-init-file -l \$(srcdir)/vm-build.el" --with-etcdir=%{_vmetcdir} --with-docdir=%{_vmdocdir}
make %{?_smp_mflags} MAKEINFO="makeinfo --force"

%install
mkdir -p %{buildroot}
%make_install
{
  echo ";; %{_datadir}/emacs/site-lisp/suse-start-%{name}.el"
  cat %{SOURCE2}
  echo ";; %{_datadir}/emacs/site-lisp/suse-start-%{name}.el ends here"
} > %{buildroot}%{_sitedir}/suse-start-%{name}.el

%if 0%{?suse_version} <= 1500
%post
%install_info --info-dir=%{_infodir} %{_infodir}/vm.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/vm.info%{ext_info}
%endif

%files
%docdir %{_vmdocdir}
%{_vmdocdir}
%dir %{_sitedir}
%{_sitedir}/*.el
%dir %{_vmdir}
%{_vmdir}/*.el
%{_vmdir}/*.elc
%{_vmdir}/version.txt
%{_bindir}/base64-encode
%{_bindir}/base64-decode
%{_bindir}/qp-decode
%{_bindir}/qp-encode
%{_infodir}/*%{ext_info}
%{_datadir}/emacs/*%{_sysconfdir}/vm/pixmaps
%dir %{_datadir}/emacs/*%{_sysconfdir}/vm
%exclude %{_datadir}/emacs/*%{_sysconfdir}/vm/README
%exclude %{_datadir}/emacs/*%{_sysconfdir}/vm/CHANGES
%exclude %{_datadir}/emacs/*%{_sysconfdir}/vm/COPYING
%exclude %{_datadir}/emacs/*%{_sysconfdir}/vm/NEWS
%exclude %{_datadir}/emacs/*%{_sysconfdir}/vm/TODO

%changelog
* Wed Mar 29 2023 Egbert Eich <eich@suse.com>
- Update to latest launchpad trunk version.
  Delete obsolete patches:
  * U_rev-1313.patch
  * U_Require-vm-reply.el-from-vm-compose-mail.patch
- Fix vcard parser to handle broken vcards better
  vcard-Make-vcard-parser-more-robust-to-invalid-vcards.patch
- Limit %%install_info and %%install_info_delete macros to Leap/SLE.
* Thu Dec  7 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Fix rpm group
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Thu Jan 21 2016 eich@suse.com
- U_Require-vm-reply.el-from-vm-compose-mail.patch
  Require vm-reply.el from vm-compose-mail (lp#913005)
  (bsc#939497).
* Mon Jul 27 2015 eich@suse.com
- U_rev-1313.patch:
  - Added a variable `vm-confirm-for-auto-archive' that controls the
    confirmation dialogue for `vm-auto-archive-messages'. (lp#793541)
  - Add autoload for `vm-select-recipient-from-sender'.  (lp#907286)
    (bsc#939497).
* Wed Mar 11 2015 dimstar@opensuse.org
- Use makeinfo --force to ignore the errors in vm.texinfo.
* Thu Oct 24 2013 eich@suse.com
- Fixed up paths to make them package private
- Removed duplicate files from package
* Thu Oct 10 2013 eich@suse.com
- Updated package to version 8.2.0b.
  * Fixes warnings about missing hooks removed from GNU emacs after being
    deprecated for over 10 years
  * Fixes performance penalties caused by bidi being activated by default
    on GNU emacs 24.
  * Updates from version 7.19 - released in 2004, 24 releases ago.
    Numerous changes and bug fixes, file 'NEWS' in the package docs list
    the changes since 7.19.
- Project now hosted at https://launchpad.net/vm.
  Upstream maintainership package has been transferred from Kyle Jones
  to the 'VM development team'.
- vm-Makefile.patch:
  Removed, matching Makefile no longer required since build uses autotools
  now.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Tue Aug 25 2009 aj@suse.de
- Fix build, handle just one info file.
* Sun Apr 22 2007 aj@suse.de
- Cleanup BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 hare@suse.de
- prepared for autobuild
- Using vm-7.19 as initial package
